## 0.12.4 (2025-08-15)

### Pull Requests

-  [`eb53657`](https://github.com/JenspederM/kedro-databricks/commit/eb53657765cecd4468de1fea7b418dde3e28b2dc): [ puneeter/fix/tests](https://github.com/JenspederM/kedro-databricks/pull/144)
-  [`f8a4d13`](https://github.com/JenspederM/kedro-databricks/commit/f8a4d13617824dc3f3c60df6bcfd740ec396530a): [ JenspederM/docs/contributing](https://github.com/JenspederM/kedro-databricks/pull/141)
-  [`b48c57d`](https://github.com/JenspederM/kedro-databricks/commit/b48c57df1049898b44db462489c4cfa04922035c): [ puneeter/fix/minor-bugs](https://github.com/JenspederM/kedro-databricks/pull/143)

### Fix

-  [`e5f74a4`](https://github.com/JenspederM/kedro-databricks/commit/e5f74a4714200e267869a1589278719d9b70a0fd):  Tests support different providers and updated asserts
-  [`a292a2f`](https://github.com/JenspederM/kedro-databricks/commit/a292a2f4a37d7ef6b9653f369d98e0db6c08aa93):  Fix tests
-  [`149196b`](https://github.com/JenspederM/kedro-databricks/commit/149196b6eb983a65ae784900a0e695fdd8892d86):  unit tests
-  [`fdc6901`](https://github.com/JenspederM/kedro-databricks/commit/fdc690153ed4c9485926774f5155ecea2e9c4cc0):  minor bugs in bundle

### Other Changes

-  [`388181f`](https://github.com/JenspederM/kedro-databricks/commit/388181f23bbb9fa19a5d063583ef2e98676586e2):  we run format during lint
-  [`47bfeff`](https://github.com/JenspederM/kedro-databricks/commit/47bfeff09cc27a15fa7534b81ed02d7e010235bc):  we also want to format
-  [`9011612`](https://github.com/JenspederM/kedro-databricks/commit/901161217f36317758bdf04ba1d300e965dd59f9):  change titles
-  [`adef928`](https://github.com/JenspederM/kedro-databricks/commit/adef92844af651e9c0d3690ec3f2f7967704ae9e):  add contribute to nav
-  [`821d3c2`](https://github.com/JenspederM/kedro-databricks/commit/821d3c2b7f683d7bca2935345e25155d470ee0a8):  we want contributing on website
-  [`8e7dd06`](https://github.com/JenspederM/kedro-databricks/commit/8e7dd06d2d0ff9f53c59c38ff3906d2bda410377):  use uv for linting
-  [`8b6214d`](https://github.com/JenspederM/kedro-databricks/commit/8b6214d4ee9a8285b9466dad835efeeb3d3127cb):  reference contributing in readme
-  [`d77a180`](https://github.com/JenspederM/kedro-databricks/commit/d77a1800646e6a48ffb6c2d499c6f1c4de00c31a):  add contributing.md

## 0.12.3 (2025-07-17)

### Pull Requests

-  [`4b3f467`](https://github.com/JenspederM/kedro-databricks/commit/4b3f467925ed73ba7b022e4662e6a73c9ae907f1): [ astrojuanlu/parse-version](https://github.com/JenspederM/kedro-databricks/pull/139)

### Fix

-  [`48bc560`](https://github.com/JenspederM/kedro-databricks/commit/48bc56029710859078f6aba90f3cffb8df9516d1):  properly parse Kedro version

## 0.12.2 (2025-07-02)

### Pull Requests

-  [`e4dcb95`](https://github.com/JenspederM/kedro-databricks/commit/e4dcb956f2070a9d32f2b760f58336134a722dc8): [ JenspederM/fix/various-minir-issues](https://github.com/JenspederM/kedro-databricks/pull/137)

### Fix

-  [`7630ae3`](https://github.com/JenspederM/kedro-databricks/commit/7630ae32f48a80fac480f0e9a842c61e152d2273):  task keys must satisfy ^[\w\-\_]+$ and be less than 100 characters
-  [`9c1c237`](https://github.com/JenspederM/kedro-databricks/commit/9c1c237a165f6859875c8a2fae95a212e6ddfc33):  use default with local storage on aws

## 0.12.1 (2025-06-17)

### Pull Requests

-  [`f8b8240`](https://github.com/JenspederM/kedro-databricks/commit/f8b8240e4deb120df80b423d408031b51a224eb5): [ JenspederM/test/version](https://github.com/JenspederM/kedro-databricks/pull/133)
-  [`e718256`](https://github.com/JenspederM/kedro-databricks/commit/e718256abf48ace4f6b155b585217d7fee16f562): [ JenspederM/fix/python3.13-support](https://github.com/JenspederM/kedro-databricks/pull/132)
-  [`951d866`](https://github.com/JenspederM/kedro-databricks/commit/951d8665708aea25c360960fad5e81210f480f5c): [ JenspederM/docs/fix-menus](https://github.com/JenspederM/kedro-databricks/pull/131)
-  [`921ae97`](https://github.com/JenspederM/kedro-databricks/commit/921ae97e0cdf65bb4a7e0d4cfef49acbb3461a52): [ astrojuanlu/patch-1](https://github.com/JenspederM/kedro-databricks/pull/130)
-  [`acd5030`](https://github.com/JenspederM/kedro-databricks/commit/acd50304b43edea17356e31b0ab71b15040edb31): [ astrojuanlu/rtd](https://github.com/JenspederM/kedro-databricks/pull/129)
-  [`b2a1472`](https://github.com/JenspederM/kedro-databricks/commit/b2a14721af304a719930955448814a6341e0d4b9): [ JenspederM/docs/use-highlighting](https://github.com/JenspederM/kedro-databricks/pull/128)

### Fix

-  [`e718256`](https://github.com/JenspederM/kedro-databricks/commit/e718256abf48ace4f6b155b585217d7fee16f562):  adds version command
-  [`14afc40`](https://github.com/JenspederM/kedro-databricks/commit/14afc4074191859370d8258500b7552c69c459c7):  add  command

### Other Changes

-  [`ce6f5ce`](https://github.com/JenspederM/kedro-databricks/commit/ce6f5cece9f45dc8634f3d1a7e548c035a5e3575):  we already have one toml dependency
-  [`71d516c`](https://github.com/JenspederM/kedro-databricks/commit/71d516c20287add45503b09255c9e3f4a4ec47e1):  remove unused parameter
-  [`ac6ac8f`](https://github.com/JenspederM/kedro-databricks/commit/ac6ac8f5c17bd7b4878fdae8afa942f1b278cb36):  assert are removed when compiling to byte code
-  [`51cb272`](https://github.com/JenspederM/kedro-databricks/commit/51cb272b7dd15242aef193fc7a72b188875a22f2):  improve devex when working in dev
-  [`afb269b`](https://github.com/JenspederM/kedro-databricks/commit/afb269b66d8556dacee041cb511f043ad23266a9):  add badges to home
-  [`cb824b1`](https://github.com/JenspederM/kedro-databricks/commit/cb824b1082d3bae864ed4745e9e80548dd1cc7fa):  CHANGELOG author is broken
-  [`452ae78`](https://github.com/JenspederM/kedro-databricks/commit/452ae787e88aa79d1c5d863b56aebc5244612e1a):  make changelog look nicer
-  [`b8bf4d5`](https://github.com/JenspederM/kedro-databricks/commit/b8bf4d55c53d7da327a7a0c541690689b84a02db):  no need for multiple menu levels
-  [`b2a1472`](https://github.com/JenspederM/kedro-databricks/commit/b2a14721af304a719930955448814a6341e0d4b9):  use hightlighted rows to keep syntax colors
-  [`f40ac2d`](https://github.com/JenspederM/kedro-databricks/commit/f40ac2d21195f3349823fafbc42ec4747390cd09):  reduce complexity
-  [`9ad2d59`](https://github.com/JenspederM/kedro-databricks/commit/9ad2d5908a22abe5d7dce7ef784952be88d0f193):  reduce complexity
-  [`8573777`](https://github.com/JenspederM/kedro-databricks/commit/8573777baeb8d99a5a8b2e1a46fb55a441d2f546):  use hightlighted rows to keep syntax colors

## 0.12.0 (2025-06-14)

### Pull Requests

-  [`840c669`](https://github.com/JenspederM/kedro-databricks/commit/840c6698dd215c73cd282e9e97c11f6684c75c15): [ JenspederM/feat/remove-py3-9-support](https://github.com/JenspederM/kedro-databricks/pull/127) (JenspederM)
-  [`c6b707d`](https://github.com/JenspederM/kedro-databricks/commit/c6b707d3d85a7f6ae9afd8384a6b50a5e851fb84): [ JenspederM/docs/init](https://github.com/JenspederM/kedro-databricks/pull/126) (JenspederM)
-  [`f3a8ca5`](https://github.com/JenspederM/kedro-databricks/commit/f3a8ca55e5e57d8d9534c3fa039dc8c8c0d7fee0): [ JenspederM/docs/init](https://github.com/JenspederM/kedro-databricks/pull/125) (JenspederM)

### Feat

-  [`6caad62`](https://github.com/JenspederM/kedro-databricks/commit/6caad62b0bb4b0d29d596d40031a5af2d0715c98):  remove python 3.9 support due to EOL in October 2025. (Jens Peder Meldgaard)

### Other Changes

-  [`32c88b5`](https://github.com/JenspederM/kedro-databricks/commit/32c88b5cdc1893a751bd7da7c8ef7bd4395a96be):  add changelog and ability to control navigation (Jens Peder Meldgaard)
-  [`c6b707d`](https://github.com/JenspederM/kedro-databricks/commit/c6b707d3d85a7f6ae9afd8384a6b50a5e851fb84):  use uv for deploying docs (JenspederM)
-  [`d142760`](https://github.com/JenspederM/kedro-databricks/commit/d142760000f5b5a86f96720256efa9958cf43b4d):  use uv for deploying docs (Jens Peder Meldgaard)
-  [`6a2f8a1`](https://github.com/JenspederM/kedro-databricks/commit/6a2f8a1f6c020d594026d9f6f7dee0d4c410fc97):  update readme (Jens Peder Meldgaard)
-  [`7f2681c`](https://github.com/JenspederM/kedro-databricks/commit/7f2681c5437fefd486aa4ac5bca24373c28aae42):  add workflow to publish docs (Jens Peder Meldgaard)
-  [`aa97ad2`](https://github.com/JenspederM/kedro-databricks/commit/aa97ad2c507c76fae8f0a4038bc7e710cb6f1777):  make stuff look nice (Jens Peder Meldgaard)
-  [`d6d9bf8`](https://github.com/JenspederM/kedro-databricks/commit/d6d9bf8a8b5c01e257077fa22565dbf69446d87a):  reduce complexity (Jens Peder Meldgaard)
-  [`7e0f078`](https://github.com/JenspederM/kedro-databricks/commit/7e0f0785a85730652f5ed542d63e6d8d25fad573):  adds diff to example result (Jens Peder Meldgaard)
-  [`e27a3bb`](https://github.com/JenspederM/kedro-databricks/commit/e27a3bb63e8a507c1045b1c99f1cd6b4302f13f1):  add readme to examples (Jens Peder Meldgaard)
-  [`3006320`](https://github.com/JenspederM/kedro-databricks/commit/3006320030da7a11f1fd9c45785502991ebd3e4f):  update docstrings (Jens Peder Meldgaard)
-  [`ebc0178`](https://github.com/JenspederM/kedro-databricks/commit/ebc01788f0c11565c528311feab3017884efbe0b):  generate markdown for examples (Jens Peder Meldgaard)
-  [`a94fbb4`](https://github.com/JenspederM/kedro-databricks/commit/a94fbb4b51555303c3765887388ee19b09287244):  setup mkdocs (Jens Peder Meldgaard)

## 0.11.0 (2025-06-13)

### Pull Requests

-  [`c4a4699`](https://github.com/JenspederM/kedro-databricks/commit/c4a4699dd8d9019598d41d10adaa666969257aa9): [ JenspederM/feat/parameters-in-conf](https://github.com/JenspederM/kedro-databricks/pull/124) (JenspederM)

### Feat

-  [`12c5a31`](https://github.com/JenspederM/kedro-databricks/commit/12c5a312f1b6b7477c174173b9aaf57ea9e3fe5e):  extend parameters instead of overriding (Jens Peder Meldgaard)

### Other Changes

-  [`9bd385a`](https://github.com/JenspederM/kedro-databricks/commit/9bd385ab9c0f86b6180f62afe422d0aad8e6f075):  switch to uv build (Jens Peder Meldgaard)

## 0.10.1 (2025-06-12)

### Pull Requests

-  [`3b92a9d`](https://github.com/JenspederM/kedro-databricks/commit/3b92a9de588459e890bc0ef80e6ac103b03e9ec3): [ JenspederM/fix/add-workspace-prefix](https://github.com/JenspederM/kedro-databricks/pull/123) (JenspederM)

### Fix

-  [`3b92a9d`](https://github.com/JenspederM/kedro-databricks/commit/3b92a9de588459e890bc0ef80e6ac103b03e9ec3):  ${workspace.file_path} is not resolved correctly regardless of what Databricks says (JenspederM)
-  [`c53c540`](https://github.com/JenspederM/kedro-databricks/commit/c53c540535e0199fcd9d38c6f396a6e43f092acb):  ${workspace.file_path} is not resolved correctly regardless of what Databricks says (Jens Peder Meldgaard)

## 0.10.0 (2025-04-25)

### Pull Requests

-  [`736b7ef`](https://github.com/JenspederM/kedro-databricks/commit/736b7ef4fd13ad3df9a0ddfa08c4705951fcba14): [ JenspederM/fix/data-upload](https://github.com/JenspederM/kedro-databricks/pull/119) (JenspederM)

### Feat

-  [`5cfc257`](https://github.com/JenspederM/kedro-databricks/commit/5cfc257fba7acfbca14743bca6c9c37a1d47246f):  adds run and destroy wrappers (Jens Peder Meldgaard)

### Fix

-  [`f52bd2a`](https://github.com/JenspederM/kedro-databricks/commit/f52bd2ad811ccc1883aa599298e44c1b808f56b1):  get everything working again (Jens Peder Meldgaard)
-  [`3e47572`](https://github.com/JenspederM/kedro-databricks/commit/3e47572c8a9d41275914fa48d2d4db6059284aee):  make default deployment work for databricks-iris starter (Jens Peder Meldgaard)
-  [`4c0d8ba`](https://github.com/JenspederM/kedro-databricks/commit/4c0d8bac51a1234ec116e5f0dd903ef6b7d4d924):  databricks does not support spark config overrides at runtime (Jens Peder Meldgaard)

### Refactor

-  [`7ff0f10`](https://github.com/JenspederM/kedro-databricks/commit/7ff0f10f3496d98630402675e058c9531c40ef4b):  switch from classes to functions (Jens Peder Meldgaard)

### Other Changes

-  [`b50f923`](https://github.com/JenspederM/kedro-databricks/commit/b50f9237cf2e5b1849957496ac2d90681616d1b9):  run integration tests when changed (Jens Peder Meldgaard)
-  [`6fdda33`](https://github.com/JenspederM/kedro-databricks/commit/6fdda33d0230b22639e2101ad9df5ebe17bdfd7c):  no need to test run separately (Jens Peder Meldgaard)
-  [`dcbeb71`](https://github.com/JenspederM/kedro-databricks/commit/dcbeb71fad5552775ea876e2bb6e99ada8b21202):  integration tests run on azure (Jens Peder Meldgaard)
-  [`2764eaa`](https://github.com/JenspederM/kedro-databricks/commit/2764eaa89981a44bd01015a059f42f77640a88ca):  no need to have two (Jens Peder Meldgaard)
-  [`1bafd40`](https://github.com/JenspederM/kedro-databricks/commit/1bafd403d544ceeb07b726c1d1916441d57d9577):  reset init between functions (Jens Peder Meldgaard)
-  [`114bf9f`](https://github.com/JenspederM/kedro-databricks/commit/114bf9f808c1dcd241df63496d849c2541a47410):  edits name (Jens Peder Meldgaard)
-  [`27936ef`](https://github.com/JenspederM/kedro-databricks/commit/27936efea1f3bf6aeef16f69def5f4b81d179310):  we only want to run one copy of databricks-iris (Jens Peder Meldgaard)
-  [`24949b5`](https://github.com/JenspederM/kedro-databricks/commit/24949b510c61565a39b1a4dbc5e2137015b67e8c):  we dont need kedro jupyter (Jens Peder Meldgaard)
-  [`8d5f675`](https://github.com/JenspederM/kedro-databricks/commit/8d5f6750a19d7fc0d4386e774c5775f59a774a17):  remove kedro version check (Jens Peder Meldgaard)
-  [`ef787d2`](https://github.com/JenspederM/kedro-databricks/commit/ef787d22aabe3a1c866744a739d9be22080a3a62):  add kedro first (Jens Peder Meldgaard)
-  [`be4c405`](https://github.com/JenspederM/kedro-databricks/commit/be4c405967545936e3baa0a03157818b375e6eba):  unit tests do not require the test group (Jens Peder Meldgaard)
-  [`a98b849`](https://github.com/JenspederM/kedro-databricks/commit/a98b849285d2f7de2489c497f4a4b289647ead6f):  allow prerelease (Jens Peder Meldgaard)
-  [`2fe11bb`](https://github.com/JenspederM/kedro-databricks/commit/2fe11bbb9b4fb76d683e4e2cf4ee4ac6dfe85cac):  install frozen (Jens Peder Meldgaard)
-  [`15daf62`](https://github.com/JenspederM/kedro-databricks/commit/15daf62825684881acf8b52980a9cf49a33dcbdc):  install all groups (Jens Peder Meldgaard)

## 0.9.1 (2025-03-22)

### Pull Requests

-  [`9ca26e5`](https://github.com/JenspederM/kedro-databricks/commit/9ca26e559b67a97ec8d7f15371a0d12c17042fac): [ JenspederM/fix/implement-all-overrides-example](https://github.com/JenspederM/kedro-databricks/pull/117) (JenspederM)

### Fix

-  [`1ba4e26`](https://github.com/JenspederM/kedro-databricks/commit/1ba4e26f902fed4c2c8bb077d4ccbcccebd0b137):  implement example for all fields in databricks jobs api 2.2 (Jens Peder Meldgaard)
-  [`03e3d74`](https://github.com/JenspederM/kedro-databricks/commit/03e3d74881964fbacd5c3069dff35cc3af0a978e):  access_control_list has multiple lookup keys (Jens Peder Meldgaard)
-  [`06aa2d1`](https://github.com/JenspederM/kedro-databricks/commit/06aa2d142f68b77ee59b5176cd02194050114b55):  add ability to ignore keyed overrides for specific fields (Jens Peder Meldgaard)
-  [`d9f2210`](https://github.com/JenspederM/kedro-databricks/commit/d9f22107070280b8b3abc2d34816ee01d1becf19):  there is no element called on_duration_failure_threshold_exceeded (Jens Peder Meldgaard)
-  [`083d81c`](https://github.com/JenspederM/kedro-databricks/commit/083d81c3381e7941e433164cd5eee9627e20a2e2):  if element is not a dict override the whole list (Jens Peder Meldgaard)

### Other Changes

-  [`124dcbc`](https://github.com/JenspederM/kedro-databricks/commit/124dcbce7daacf80a8f423099725d5112012b30e):  add missing field to email notifications (Jens Peder Meldgaard)

## 0.9.0 (2025-03-20)

### Pull Requests

-  [`e6cd630`](https://github.com/JenspederM/kedro-databricks/commit/e6cd6306fc51ad9b7786bf4ccaf11295e844c880): [ JenspederM/fix/implement-all-override-keys](https://github.com/JenspederM/kedro-databricks/pull/115) (JenspederM)
-  [`88a54bb`](https://github.com/JenspederM/kedro-databricks/commit/88a54bbb6acd98c1db4be87016fb119e59c165b3): [ npfp/feat/runtime_params](https://github.com/JenspederM/kedro-databricks/pull/96) (JenspederM)

### Fix

-  [`f298b78`](https://github.com/JenspederM/kedro-databricks/commit/f298b78f63c0eb423ec6a310150fe6d5e2b987d5):  rename params and conf-source  according to kedro (Jens Peder Meldgaard)
-  [`93eb34d`](https://github.com/JenspederM/kedro-databricks/commit/93eb34dc4659a27c92bab4879222a8083dada0e3):  add support for custom task libraries (Jens Peder Meldgaard)
-  [`c1bb870`](https://github.com/JenspederM/kedro-databricks/commit/c1bb87049cd6e153f46cae27f236120158b4f09d):  add support for job parameters (Jens Peder Meldgaard)
-  [`6c78de3`](https://github.com/JenspederM/kedro-databricks/commit/6c78de3cd69f63f053122a6313020cdd9f8c1c14):  add support for health rule overrides (Jens Peder Meldgaard)

### Refactor

-  [`39b4250`](https://github.com/JenspederM/kedro-databricks/commit/39b4250f626a5a421ce6bf126e506b21b92ac87d):  achieve the same with way less code (Jens Peder Meldgaard)
-  [`f3cebca`](https://github.com/JenspederM/kedro-databricks/commit/f3cebcafe1d23a91a37149b85dfb4b71e64406c0):  move utils only used for bundling to separate module (Jens Peder Meldgaard)
-  [`d17d2d5`](https://github.com/JenspederM/kedro-databricks/commit/d17d2d5e581ebfcbbe9916d8f2b05dd075a1d957):  move examples path resolution to where it's used (Jens Peder Meldgaard)
-  [`71d7ded`](https://github.com/JenspederM/kedro-databricks/commit/71d7ded17a12a99998271d176cd41229f109df13):  move remove_nulls to separate module (Jens Peder Meldgaard)
-  [`e54500b`](https://github.com/JenspederM/kedro-databricks/commit/e54500b843bd98a24a4c4fa18c1c04043d89835b):  use help from kedro where possible (Jens Peder Meldgaard)

### Other Changes

-  [`773e175`](https://github.com/JenspederM/kedro-databricks/commit/773e175ace5d2b3a102cd55032be04aa0706e612):  type error (Jens Peder Meldgaard)
-  [`c79aa98`](https://github.com/JenspederM/kedro-databricks/commit/c79aa98e34bb9637ca2d7f03bd01c700c335eb5a):  yaml lint pre-commit (Jens Peder Meldgaard)
-  [`782652e`](https://github.com/JenspederM/kedro-databricks/commit/782652e943ab1902b6e944fa31d1b70a051daf48):  check-otml and fix line endings (Jens Peder Meldgaard)
-  [`402d461`](https://github.com/JenspederM/kedro-databricks/commit/402d461adc8e56ffe2867355314b6f6af7e1f1ac):  add no cover (Jens Peder Meldgaard)
-  [`e762534`](https://github.com/JenspederM/kedro-databricks/commit/e762534e1e59888e7f027b3ed02acf711173815c):  add example for task level webhook notifications (Jens Peder Meldgaard)
-  [`63aa628`](https://github.com/JenspederM/kedro-databricks/commit/63aa62824de01b55e5130c5f122667b0eabf9a7f):  move to webhook_notifications (Jens Peder Meldgaard)

## 0.8.1 (2025-03-15)

### Pull Requests

-  [`14eb8b3`](https://github.com/JenspederM/kedro-databricks/commit/14eb8b3fb938a3c6303f51c45145d33fd4086a61): [ JenspederM/fix/keyed-overrides](https://github.com/JenspederM/kedro-databricks/pull/114) (JenspederM)

### Fix

-  [`14eb8b3`](https://github.com/JenspederM/kedro-databricks/commit/14eb8b3fb938a3c6303f51c45145d33fd4086a61):  webhook overrides are keyed (JenspederM)
-  [`1fabb55`](https://github.com/JenspederM/kedro-databricks/commit/1fabb55a8b7db65ef7223c9ab8b8e6933c7306f0):  webhook overrides are keyed (Jens Peder Meldgaard)

## 0.8.0 (2025-03-09)

### Pull Requests

-  [`66a8548`](https://github.com/JenspederM/kedro-databricks/commit/66a854826f39ecc35b2969f2515c54dac02e20db): [ JenspederM/feat/forward-args](https://github.com/JenspederM/kedro-databricks/pull/109) (JenspederM)

### Feat

-  [`04e5526`](https://github.com/JenspederM/kedro-databricks/commit/04e552668f3a3796cc13df15be8496de4a210a14):  create target specific configurations (Jens Peder Meldgaard)
-  [`b88e18c`](https://github.com/JenspederM/kedro-databricks/commit/b88e18c79426cd4cb297076a33f9caedd1c36e93):  let asset bundle handle file sync (Jens Peder Meldgaard)
-  [`d239944`](https://github.com/JenspederM/kedro-databricks/commit/d2399440d276ebbb20d1b63db734e41a87747bc5):  kedro_databricks is now type safe (Jens Peder Meldgaard)
-  [`e2f6fed`](https://github.com/JenspederM/kedro-databricks/commit/e2f6fed1121dd67022b73f5f46999e7af1dd5b1c):  pass args to databricks cli directly (Jens Peder Meldgaard)

### Fix

-  [`f48039b`](https://github.com/JenspederM/kedro-databricks/commit/f48039b757606d9ed21f7ca0d9d3cba3cdf137a3):  update gitignore (Jens Peder Meldgaard)
-  [`1daf1b7`](https://github.com/JenspederM/kedro-databricks/commit/1daf1b7012475851deef3f9fb421f76f7f990b13):  deploy to env by default (Jens Peder Meldgaard)
-  [`cdfaa2f`](https://github.com/JenspederM/kedro-databricks/commit/cdfaa2fd9de983e853c451f877fa154aa6ec3e49):  elements are popped from overrides (Jens Peder Meldgaard)
-  [`8b27f63`](https://github.com/JenspederM/kedro-databricks/commit/8b27f63638e55c34ec1913b805e0741dba95fc24):  make bundling work (Jens Peder Meldgaard)
-  [`099c08c`](https://github.com/JenspederM/kedro-databricks/commit/099c08c0c1363a9a29e69a2157d82aa513964fd3):  get target from databricks args (Jens Peder Meldgaard)
-  [`6ed196b`](https://github.com/JenspederM/kedro-databricks/commit/6ed196b312d5b9000cc816ae39b7dcd164e62e90):  check if user is using databricks cli version (Jens Peder Meldgaard)
-  [`9384a30`](https://github.com/JenspederM/kedro-databricks/commit/9384a30383c40d17492f3398e295213f03fd4478):  real time forward stdout from commands (Jens Peder Meldgaard)
-  [`0af3989`](https://github.com/JenspederM/kedro-databricks/commit/0af3989f88432f6de1d38ec348022b8244bac76f):  ensures that unit tests can run locally (Jens Peder Meldgaard)

### Other Changes

-  [`eaa344a`](https://github.com/JenspederM/kedro-databricks/commit/eaa344a49e4da6fdeb6b41cb742e33a4e06789ae):  add environements lookup key to OVERRIDE_KEY_MAP (Jens Peder Meldgaard)
-  [`7745c1a`](https://github.com/JenspederM/kedro-databricks/commit/7745c1ab335db249a038e7576c5b0f13db9a5610):  use named function arguments (Jens Peder Meldgaard)
-  [`c82ff22`](https://github.com/JenspederM/kedro-databricks/commit/c82ff2284d59098447d4f44e04566dbe62f4de1b):  reduce complexity (Jens Peder Meldgaard)
-  [`35be554`](https://github.com/JenspederM/kedro-databricks/commit/35be554198f3264a66ceb514239e5bc3346debdc):  reduce complexity (Jens Peder Meldgaard)
-  [`3a97597`](https://github.com/JenspederM/kedro-databricks/commit/3a97597c7bbdc9c5eef28e31262810cf2018fe09):  Workspace paths are now automatically prefixed with /Workspace (Jens Peder Meldgaard)
-  [`406b4c9`](https://github.com/JenspederM/kedro-databricks/commit/406b4c915e4f67505e427a2678821317ff4a872f):  fix type hints (Jens Peder Meldgaard)
-  [`69c83d5`](https://github.com/JenspederM/kedro-databricks/commit/69c83d5ad396cf5a31b947f218d661ec1d94e438):  unit tests now require databricks cli (Jens Peder Meldgaard)
-  [`b2ebb86`](https://github.com/JenspederM/kedro-databricks/commit/b2ebb8634e31160b6953f4a40ecc9bc4b13c8f89):  update uv (Jens Peder Meldgaard)
-  [`86473d5`](https://github.com/JenspederM/kedro-databricks/commit/86473d55c1fe228892df010821bd7b0c68eb1014):  reduce code complexity (Jens Peder Meldgaard)
-  [`0221c6a`](https://github.com/JenspederM/kedro-databricks/commit/0221c6ac138d5869caec8be0aec2bce23e0bc099):  default should be a unity catalog enabled cluster (Jens Peder Meldgaard)

## 0.7.4 (2025-02-13)

### Pull Requests

-  [`00d6cac`](https://github.com/JenspederM/kedro-databricks/commit/00d6cac71b77fd59461a2d51dbd577fd7c9c5faa): [ JenspederM/chore/change-src](https://github.com/JenspederM/kedro-databricks/pull/108) (JenspederM)
-  [`4472bd5`](https://github.com/JenspederM/kedro-databricks/commit/4472bd5052ce9630cb5073f19a01f4a53e4a5fce): [ JenspederM/fix/use-non-deprecated-download](https://github.com/JenspederM/kedro-databricks/pull/107) (JenspederM)

### Fix

-  [`bdd9283`](https://github.com/JenspederM/kedro-databricks/commit/bdd92838f90464ec27b40aacf6788d89bc61e050):  v2 is deprecated (Jens Peder Meldgaard)

### Other Changes

-  [`00d6cac`](https://github.com/JenspederM/kedro-databricks/commit/00d6cac71b77fd59461a2d51dbd577fd7c9c5faa):  import docstring (JenspederM)
-  [`4472bd5`](https://github.com/JenspederM/kedro-databricks/commit/4472bd5052ce9630cb5073f19a01f4a53e4a5fce):  use non deprecated download (JenspederM)
-  [`53af87b`](https://github.com/JenspederM/kedro-databricks/commit/53af87be39c8cff23571d31547c9bd7214bfb4a0):  import docstring (Jens Peder Meldgaard)

## 0.7.3 (2025-02-13)

### Pull Requests

-  [`0ff9154`](https://github.com/JenspederM/kedro-databricks/commit/0ff9154af6dd404fcf7fd041330341ef4439f171): [ JenspederM/fix/refactor-databricks-success](https://github.com/JenspederM/kedro-databricks/pull/106) (JenspederM)
-  [`dd66576`](https://github.com/JenspederM/kedro-databricks/commit/dd66576845cc662ccfb0365df01b987b5cc62f34): [ JenspederM/ci/pull-generated-tag](https://github.com/JenspederM/kedro-databricks/pull/105) (JenspederM)

### Fix

-  [`0ff9154`](https://github.com/JenspederM/kedro-databricks/commit/0ff9154af6dd404fcf7fd041330341ef4439f171):  refactor databricks success check (JenspederM)
-  [`4a96da1`](https://github.com/JenspederM/kedro-databricks/commit/4a96da127fde5d3c3713e4c6e698f0fe81c2cd54):  refactor databricks success check (Jens Peder Meldgaard)
-  [`dd66576`](https://github.com/JenspederM/kedro-databricks/commit/dd66576845cc662ccfb0365df01b987b5cc62f34):  upload changelog when checking version (JenspederM)

## 0.7.2 (2025-02-13)

### Pull Requests

-  [`a80391b`](https://github.com/JenspederM/kedro-databricks/commit/a80391be877f52846e82b17d8b13b04b77fad899): [ JenspederM/ci/pull-generated-tag](https://github.com/JenspederM/kedro-databricks/pull/104) (JenspederM)

### Fix

-  [`d10ba47`](https://github.com/JenspederM/kedro-databricks/commit/d10ba4719d72947294c540d174f9e07dca50b5a6):  upload changelog when checking version (Jens Peder Meldgaard)
-  [`cb00b23`](https://github.com/JenspederM/kedro-databricks/commit/cb00b23e26b55145e4490f9319b4be6b945e8800):  make success check a variable (Jens Peder Meldgaard)

### Other Changes

-  [`7050621`](https://github.com/JenspederM/kedro-databricks/commit/705062156cd8723b7cc472dd7492f6dd8a9117d3):  update bagde (Jens Peder Meldgaard)
-  [`d8b5066`](https://github.com/JenspederM/kedro-databricks/commit/d8b50667131a155447a87bd5d80e6dcf1533e519):  pull tag based on version check (Jens Peder Meldgaard)

## 0.7.1 (2025-02-13)

### Pull Requests

-  [`bb07c08`](https://github.com/JenspederM/kedro-databricks/commit/bb07c08e44ea8063bfeae9c0de617b5eb0545a9f): [ JenspederM/fix/tar-output-is-always-conf](https://github.com/JenspederM/kedro-databricks/pull/103) (JenspederM)
-  [`8fbb4fe`](https://github.com/JenspederM/kedro-databricks/commit/8fbb4fedd1f6b0d4b2c5d33591a5b4bd52a17c7e): [ JenspederM/fix/tar-output-is-always-conf](https://github.com/JenspederM/kedro-databricks/pull/102) (JenspederM)
-  [`dd0c5a8`](https://github.com/JenspederM/kedro-databricks/commit/dd0c5a8c089198abafbab9b82cd2854b956da19a): [ JenspederM/ci/random-fixes](https://github.com/JenspederM/kedro-databricks/pull/100) (JenspederM)
-  [`5728861`](https://github.com/JenspederM/kedro-databricks/commit/5728861b6d0f3feab99a85224e983e462e394b8e): [ JenspederM/ci/remember-checkout](https://github.com/JenspederM/kedro-databricks/pull/95) (JenspederM)
-  [`110a78c`](https://github.com/JenspederM/kedro-databricks/commit/110a78ca911136e988d313147a78a1d95609bd7b): [ JenspederM/ci/remember-checkout](https://github.com/JenspederM/kedro-databricks/pull/94) (JenspederM)

### Fix

-  [`4cee54e`](https://github.com/JenspederM/kedro-databricks/commit/4cee54ea5a8ea9b6dc4661337466d464fc3b134d):  avoid nesting conf dir (Jens Peder Meldgaard)

### Other Changes

-  [`ccb7d33`](https://github.com/JenspederM/kedro-databricks/commit/ccb7d332776af52ac34cf56e22515c6b0da34b98):  Command should have a sensible default msg (Jens Peder Meldgaard)
-  [`c51dae6`](https://github.com/JenspederM/kedro-databricks/commit/c51dae673e008604736b266412f2675976722f1a):  Command should use self.msg when logging (Jens Peder Meldgaard)
-  [`4fa05ee`](https://github.com/JenspederM/kedro-databricks/commit/4fa05eeb851ceaa831ff6845f1e3a4bc89178339):  contents: write should allow contributors to make a PR comment (Jens Peder Meldgaard)
-  [`b884920`](https://github.com/JenspederM/kedro-databricks/commit/b88492085e8d4b444758d758cb8129cd56c23cbd):  only publish on changes to src or tests (Jens Peder Meldgaard)
-  [`5728861`](https://github.com/JenspederM/kedro-databricks/commit/5728861b6d0f3feab99a85224e983e462e394b8e):  print new veersion (JenspederM)
-  [`a5c8b72`](https://github.com/JenspederM/kedro-databricks/commit/a5c8b724644fb2ce73ff20546c9dcb10bb1336ea):  print new veersion (Jens Peder Meldgaard)
-  [`110a78c`](https://github.com/JenspederM/kedro-databricks/commit/110a78ca911136e988d313147a78a1d95609bd7b):  print new veersion (JenspederM)
-  [`8d3cfee`](https://github.com/JenspederM/kedro-databricks/commit/8d3cfeeaebea77059a879b1a3ae6651f68c4fefd):  print new veersion (Jens Peder Meldgaard)

## 0.7.0 (2025-01-03)

### Pull Requests

-  [`49dcb65`](https://github.com/JenspederM/kedro-databricks/commit/49dcb65ae45b330db45d1ec2802fd496f7f5505c): [ JenspederM/ci/remember-checkout](https://github.com/JenspederM/kedro-databricks/pull/93) (JenspederM)
-  [`cffb7f8`](https://github.com/JenspederM/kedro-databricks/commit/cffb7f876684519965f455a2f91042fa1a4e8091): [ JenspederM/ci/integration-test-on-call](https://github.com/JenspederM/kedro-databricks/pull/92) (JenspederM)
-  [`1eb805a`](https://github.com/JenspederM/kedro-databricks/commit/1eb805a24726f20be9ef3f95b08358d6787a5bc0): [ JenspederM/ci/integration-test-on-call](https://github.com/JenspederM/kedro-databricks/pull/91) (JenspederM)

### Feat

-  [`4b852b3`](https://github.com/JenspederM/kedro-databricks/commit/4b852b34a60bddf220ad1cecce806c0014bea0e2):  check for version (Jens Peder Meldgaard)
-  [`4b852b3`](https://github.com/JenspederM/kedro-databricks/commit/4b852b34a60bddf220ad1cecce806c0014bea0e2):  check for version before publish (Jens Peder Meldgaard)
-  [`4b852b3`](https://github.com/JenspederM/kedro-databricks/commit/4b852b34a60bddf220ad1cecce806c0014bea0e2):  check for version before publish (Jens Peder Meldgaard)

### Other Changes

-  [`49dcb65`](https://github.com/JenspederM/kedro-databricks/commit/49dcb65ae45b330db45d1ec2802fd496f7f5505c):  forgot checkout (JenspederM)
-  [`4158dfb`](https://github.com/JenspederM/kedro-databricks/commit/4158dfbbe1528f61d77c95f2cf359f640fd74c79):  forgot checkout (Jens Peder Meldgaard)
-  [`79fd818`](https://github.com/JenspederM/kedro-databricks/commit/79fd818fccbaed46904678f33b9e2fc6ed1714e3):  change comment author (Jens Peder Meldgaard)
-  [`b6cad81`](https://github.com/JenspederM/kedro-databricks/commit/b6cad814a2b7799731986457612727662bc18546):  add reusable action for checking version (Jens Peder Meldgaard)
-  [`4ed8b0a`](https://github.com/JenspederM/kedro-databricks/commit/4ed8b0ab377724b296c77be0fab9f0100722d751):  add linting (Jens Peder Meldgaard)
-  [`4b852b3`](https://github.com/JenspederM/kedro-databricks/commit/4b852b34a60bddf220ad1cecce806c0014bea0e2):  display version on pr (Jens Peder Meldgaard)
-  [`4b852b3`](https://github.com/JenspederM/kedro-databricks/commit/4b852b34a60bddf220ad1cecce806c0014bea0e2):  echo new version (Jens Peder Meldgaard)
-  [`169e88f`](https://github.com/JenspederM/kedro-databricks/commit/169e88fc13625e054bf3b075aedb51e71cb07434):  migrate to uv (Jens Peder Meldgaard)
-  [`169e88f`](https://github.com/JenspederM/kedro-databricks/commit/169e88fc13625e054bf3b075aedb51e71cb07434):  migrate to uv (Jens Peder Meldgaard)
-  [`169e88f`](https://github.com/JenspederM/kedro-databricks/commit/169e88fc13625e054bf3b075aedb51e71cb07434):  add permissions (Jens Peder Meldgaard)
-  [`169e88f`](https://github.com/JenspederM/kedro-databricks/commit/169e88fc13625e054bf3b075aedb51e71cb07434):  run unit tests with correct python version (Jens Peder Meldgaard)
-  [`1affa8f`](https://github.com/JenspederM/kedro-databricks/commit/1affa8fb1a7d2c8fbde9c3bf543192f921429252):  remove comment (Jens Peder Meldgaard)
-  [`aaebf2c`](https://github.com/JenspederM/kedro-databricks/commit/aaebf2c36d0f603d6bfd83fc37b4919c74c814fb):  remove whitespace (Jens Peder Meldgaard)
-  [`a2f0846`](https://github.com/JenspederM/kedro-databricks/commit/a2f0846d248de7b2073fda4508a53527ebb8784e):  pass secrets to workflow (Jens Peder Meldgaard)

## 0.6.7 (2024-12-28)

### Pull Requests

-  [`9a211b5`](https://github.com/JenspederM/kedro-databricks/commit/9a211b57e340e0c8b1500da94545121fdb2786af): [ JenspederM/test/deploy-test-fail](https://github.com/JenspederM/kedro-databricks/pull/90) (JenspederM)
-  [`53e431b`](https://github.com/JenspederM/kedro-databricks/commit/53e431bdb4d08520500ba1338df3539b315342bf): [ JenspederM/test/deploy-test-fail](https://github.com/JenspederM/kedro-databricks/pull/89) (JenspederM)
-  [`4e24edb`](https://github.com/JenspederM/kedro-databricks/commit/4e24edb90fba5b58148133a5d464358cf9f78894): [ JenspederM/test/deploy-test-fail](https://github.com/JenspederM/kedro-databricks/pull/88) (JenspederM)
-  [`d2c528c`](https://github.com/JenspederM/kedro-databricks/commit/d2c528c5540a85adb3009c576b71f72889fe8ea7): [ JenspederM/test/deploy-test-fail](https://github.com/JenspederM/kedro-databricks/pull/87) (JenspederM)
-  [`6868caa`](https://github.com/JenspederM/kedro-databricks/commit/6868caad3722a2503a69b9a4d1053bf3f9c8104d): [ JenspederM/test/deploy-test-fail](https://github.com/JenspederM/kedro-databricks/pull/86) (JenspederM)
-  [`1045bad`](https://github.com/JenspederM/kedro-databricks/commit/1045bad038c28a5678ec3c8054c8c70a4e51cec1): [ JenspederM/test/deploy-test-fail](https://github.com/JenspederM/kedro-databricks/pull/85) (JenspederM)
-  [`d34ad69`](https://github.com/JenspederM/kedro-databricks/commit/d34ad69b44aeb21e9cec05929653c70df4b716bd): [ JenspederM/fix/tarfile-filter](https://github.com/JenspederM/kedro-databricks/pull/84) (JenspederM)
-  [`e5a4255`](https://github.com/JenspederM/kedro-databricks/commit/e5a425516c9807b9480aedbfde651522508b041f): [ JenspederM/test/log_deployed_resources](https://github.com/JenspederM/kedro-databricks/pull/82) (JenspederM)

### Fix

-  [`1045bad`](https://github.com/JenspederM/kedro-databricks/commit/1045bad038c28a5678ec3c8054c8c70a4e51cec1):  allow usage of environment variables to configure workspace client (JenspederM)
-  [`743c7f0`](https://github.com/JenspederM/kedro-databricks/commit/743c7f07d3d8495ae1e39f0312d79a1ffb6823cc):  allow usage of environment variables to configure workspace client (Jens Peder Meldgaard)
-  [`1813f31`](https://github.com/JenspederM/kedro-databricks/commit/1813f3170229103d9cc4c0f1113e136a0776d816):  command should return CompletedProcess (Jens Peder Meldgaard)
-  [`e5a0252`](https://github.com/JenspederM/kedro-databricks/commit/e5a02522b1c6e2b3eb5d34092b36b709ff3666e6):  tarfile fitler was implemented in python 3.12 (Jens Peder Meldgaard)
-  [`86a24c8`](https://github.com/JenspederM/kedro-databricks/commit/86a24c8e197e5aa52d7ae9a0a1092bd12f0bbd92):  completion logging was unreachable (Jens Peder Meldgaard)

### Refactor

-  [`5149662`](https://github.com/JenspederM/kedro-databricks/commit/51496629e858e1081c490450196f3290c914e9f3):  command run (Jens Peder Meldgaard)

### Other Changes

-  [`d2c528c`](https://github.com/JenspederM/kedro-databricks/commit/d2c528c5540a85adb3009c576b71f72889fe8ea7):  add sanity check (JenspederM)
-  [`c062c9a`](https://github.com/JenspederM/kedro-databricks/commit/c062c9aa4a593efab976ec6127505cd89fd4c3a0):  add sanity check (Jens Peder Meldgaard)
-  [`517f3b7`](https://github.com/JenspederM/kedro-databricks/commit/517f3b7d74128263b8d60906d292296653bbe426):  add sanity check (Jens Peder Meldgaard)

## 0.6.6 (2024-11-28)

### Pull Requests

-  [`5a24a9d`](https://github.com/JenspederM/kedro-databricks/commit/5a24a9dccbed6e3739f013535fd37472e651b4c5): [ JenspederM/fix/add-support-for-vars](https://github.com/JenspederM/kedro-databricks/pull/80) (JenspederM)

### Fix

-  [`5a24a9d`](https://github.com/JenspederM/kedro-databricks/commit/5a24a9dccbed6e3739f013535fd37472e651b4c5):  add support for vars (JenspederM)
-  [`fbaf166`](https://github.com/JenspederM/kedro-databricks/commit/fbaf166b1f5e6115cc1abfc4f035e48b4b81a741):  it's var not vars (Jens Peder Meldgaard)
-  [`5bcb934`](https://github.com/JenspederM/kedro-databricks/commit/5bcb934cd433f88a483067f465cad98b3bbcc88b):  add support for vars (Jens Peder Meldgaard)

### Refactor

-  [`0f2180c`](https://github.com/JenspederM/kedro-databricks/commit/0f2180c01d4a366884dc955a26060a441f152c82):  improve run command (Jens Peder Meldgaard)

## 0.6.5 (2024-11-24)

### Pull Requests

-  [`b15734e`](https://github.com/JenspederM/kedro-databricks/commit/b15734ef2da0de090db2a31c9d35d80447b6d517): [ JenspederM/test/fix_import](https://github.com/JenspederM/kedro-databricks/pull/78) (JenspederM)
-  [`ff4a392`](https://github.com/JenspederM/kedro-databricks/commit/ff4a39295b5060d85dd2be1fc55756e063e044f7): [ JenspederM/fix/enhance-deploy-info](https://github.com/JenspederM/kedro-databricks/pull/75) (JenspederM)

### Fix

-  [`3bfef43`](https://github.com/JenspederM/kedro-databricks/commit/3bfef43edb0d13b6faa0aaeec72b1a24d61e766f):  log deployed jobs to user (Jens Peder Meldgaard)

### Refactor

-  [`8b7feb0`](https://github.com/JenspederM/kedro-databricks/commit/8b7feb038df67d91411dbc5999f44198a875c518):  make _gather_jobs easier to test (Jens Peder Meldgaard)
-  [`791df6d`](https://github.com/JenspederM/kedro-databricks/commit/791df6d98ae579855fdd42fa7102a877de780bdf):  add types to deploy methods (Jens Peder Meldgaard)
-  [`3f6979a`](https://github.com/JenspederM/kedro-databricks/commit/3f6979a8241b8dc9ac66e61d4a034d853274dd8a):  simplify log_deployed_resources (Jens Peder Meldgaard)
-  [`b4da364`](https://github.com/JenspederM/kedro-databricks/commit/b4da3643f081815929d6c6018efe8b5a5c12c0f6):  return jobs after logging (Jens Peder Meldgaard)
-  [`5af7a97`](https://github.com/JenspederM/kedro-databricks/commit/5af7a972dcaaefe83cc7f6ce358b08db6cbbd53b):  handle errors in init (Jens Peder Meldgaard)
-  [`a999604`](https://github.com/JenspederM/kedro-databricks/commit/a99960434e23c27342bd2fb28549dae1eb6143ed):  fix args in make_workflow_name (Jens Peder Meldgaard)
-  [`2987fdd`](https://github.com/JenspederM/kedro-databricks/commit/2987fddb587be823c78bac1665f2ae7e9f4cc65f):  move make_workflow_name to utils (Jens Peder Meldgaard)

### Other Changes

-  [`d5a1fa4`](https://github.com/JenspederM/kedro-databricks/commit/d5a1fa45798f0d5d095560c07ba2fb9286553aa3):  remove __main__ (Jens Peder Meldgaard)
-  [`3ad6675`](https://github.com/JenspederM/kedro-databricks/commit/3ad6675e5344a0ba5188db74767f29468b2dd2bc):  use uv for dev builds (Jens Peder Meldgaard)
-  [`bc322f3`](https://github.com/JenspederM/kedro-databricks/commit/bc322f3a8b1661e5d9386c82cbc4332d808a81c6):  add databricks-sdk as dependency (Jens Peder Meldgaard)

## 0.6.4 (2024-11-06)

### Pull Requests

-  [`053b4c9`](https://github.com/JenspederM/kedro-databricks/commit/053b4c9bc7c5395c92cc7a5bf53c414f7b70708b): [ JenspederM/refactor/make-deploy-a-controller](https://github.com/JenspederM/kedro-databricks/pull/74) (JenspederM)

### Refactor

-  [`4ab7698`](https://github.com/JenspederM/kedro-databricks/commit/4ab7698f995bcebdc0a7e887044730058414a987):  simplify generate_resources (Jens Peder Meldgaard)
-  [`3d7dca6`](https://github.com/JenspederM/kedro-databricks/commit/3d7dca6ecc287f8d0f2b8892bce2df11e9055c56):  make deploy a controller (Jens Peder Meldgaard)

### Other Changes

-  [`4c1f3d6`](https://github.com/JenspederM/kedro-databricks/commit/4c1f3d60c72c5b85ce28963abc797fd3463d4203):  update dependencies and remove unused dev dependencies (Jens Peder Meldgaard)
-  [`c09cd83`](https://github.com/JenspederM/kedro-databricks/commit/c09cd83ad45e18a03c64a1da060987540377481c):  update pre-commits (Jens Peder Meldgaard)

## 0.6.3 (2024-11-06)

### Pull Requests

-  [`5d6634f`](https://github.com/JenspederM/kedro-databricks/commit/5d6634fff6590351fcbdf1e8d09bbba1db639636): [ npfp/refactor/sort-task-dependencies](https://github.com/JenspederM/kedro-databricks/pull/73) (JenspederM)

## 0.6.2 (2024-11-02)

### Pull Requests

-  [`151adf6`](https://github.com/JenspederM/kedro-databricks/commit/151adf67def639ad7d0f929abbfc5a74a8866192): [ JenspederM/fix/pass-args-to-bundle-controller](https://github.com/JenspederM/kedro-databricks/pull/71) (JenspederM)
-  [`4fc2396`](https://github.com/JenspederM/kedro-databricks/commit/4fc23965800f82c2dba2330b5a07a194df9412cc): [ JenspederM/refactor/make-bundle-a-controller](https://github.com/JenspederM/kedro-databricks/pull/67) (JenspederM)

### Fix

-  [`151adf6`](https://github.com/JenspederM/kedro-databricks/commit/151adf67def639ad7d0f929abbfc5a74a8866192):  pass init args to bundle controller in deploy (JenspederM)
-  [`5c7cd55`](https://github.com/JenspederM/kedro-databricks/commit/5c7cd55511f90ab116ccc980586fc59787291eb2):  make overwrite arg a flag (Jens Peder Meldgaard)
-  [`4413554`](https://github.com/JenspederM/kedro-databricks/commit/44135543ab004e5293576f3f2c1c62ec62e022bb):  pass init args to bundle controller in deploy (Jens Peder Meldgaard)

### Refactor

-  [`ef03f5c`](https://github.com/JenspederM/kedro-databricks/commit/ef03f5cbec9081ffe0f353e6925fa00889a2b064):  make bundle a controller (Jens Peder Meldgaard)

### Other Changes

-  [`1ae98c4`](https://github.com/JenspederM/kedro-databricks/commit/1ae98c4942c81d5b1739b99eb2fa41882224c661):  update kedro (Jens Peder Meldgaard)
-  [`d045018`](https://github.com/JenspederM/kedro-databricks/commit/d0450186d79466bd80c2bafd096bb8ad7b3a2c91):  satisfy lint (Jens Peder Meldgaard)
-  [`ba197b5`](https://github.com/JenspederM/kedro-databricks/commit/ba197b514994feb8c5d729f2a5f4b59c065455af):  update dependencies (Jens Peder Meldgaard)
-  [`15122e6`](https://github.com/JenspederM/kedro-databricks/commit/15122e6a4632ef6956749cc3899ddb1d03df41fb):  remove black from pre-commit (Jens Peder Meldgaard)

## 0.6.1 (2024-10-26)

### Pull Requests

-  [`9807739`](https://github.com/JenspederM/kedro-databricks/commit/9807739b3b83a899766afe58edd45b30e9a63a45): [ JenspederM/ci/add-body-to-release](https://github.com/JenspederM/kedro-databricks/pull/66) (JenspederM)
-  [`7ac9d56`](https://github.com/JenspederM/kedro-databricks/commit/7ac9d56cab6a0e8362a3c14cf73a8f1e380b09c6): [ JenspederM/test/fix_init_test](https://github.com/JenspederM/kedro-databricks/pull/65) (JenspederM)
-  [`de587f1`](https://github.com/JenspederM/kedro-databricks/commit/de587f198d051c863d0f40f295405398dd0babf4): [ JenspederM/refactor/init](https://github.com/JenspederM/kedro-databricks/pull/64) (JenspederM)

### Refactor

-  [`c8e9a15`](https://github.com/JenspederM/kedro-databricks/commit/c8e9a15b8b568828bc54437953627db724cdd856):  add utility to check if user has databricks CLI (JensPederM)
-  [`0be5a5c`](https://github.com/JenspederM/kedro-databricks/commit/0be5a5c200b328387eaca8352185916597ac800e):  move init templates to separate folder (JensPederM)
-  [`1045577`](https://github.com/JenspederM/kedro-databricks/commit/104557773d81c1fbca753970414b9a7280d3be9b):  make init a class to reduce duplicated code (JensPederM)

### Other Changes

-  [`9807739`](https://github.com/JenspederM/kedro-databricks/commit/9807739b3b83a899766afe58edd45b30e9a63a45):  add increment changelog to release body (JenspederM)
-  [`4eea65f`](https://github.com/JenspederM/kedro-databricks/commit/4eea65f0a8ede05174cd5988ddeba732ff1969e2):  add increment changelog to release body (Jens Peder Meldgaard)

## 0.6.0 (2024-10-20)

### Pull Requests

-  [`791d9d3`](https://github.com/JenspederM/kedro-databricks/commit/791d9d3067ca49c57ff07f0fd173a88b789d3f05): [ npfp/feat/bundle-single-pipeline](https://github.com/JenspederM/kedro-databricks/pull/63) (JenspederM)

## 0.5.0 (2024-10-17)

### Pull Requests

-  [`4ecb979`](https://github.com/JenspederM/kedro-databricks/commit/4ecb9795667f80bd51523a7e8406055694883455): [ npfp/feat/sort-tasks](https://github.com/JenspederM/kedro-databricks/pull/62) (JenspederM)
-  [`35e4ade`](https://github.com/JenspederM/kedro-databricks/commit/35e4ade7a3b0f7a304cfcc571dce091e380b7920): [ noklam/patch-2](https://github.com/JenspederM/kedro-databricks/pull/61) (JenspederM)

## 0.4.0 (2024-10-05)

### Pull Requests

-  [`d0f6ef9`](https://github.com/JenspederM/kedro-databricks/commit/d0f6ef9f169b2bea5267b28b6ad17e13f0b45b9b): [ JenspederM/fix/add-support-for-other-conf-paths](https://github.com/JenspederM/kedro-databricks/pull/59) (JenspederM)
-  [`5a31092`](https://github.com/JenspederM/kedro-databricks/commit/5a3109234a8d88cea1cd72d0d8e6a72d12d4d0e3): [ JenspederM/test/separate_unit_integration](https://github.com/JenspederM/kedro-databricks/pull/57) (JenspederM)
-  [`32115d3`](https://github.com/JenspederM/kedro-databricks/commit/32115d3f00d1f570ab14aab22ed230f3607f1dc1): [ JenspederM/test/separate_unit_integration](https://github.com/JenspederM/kedro-databricks/pull/56) (JenspederM)
-  [`f3bd5ff`](https://github.com/JenspederM/kedro-databricks/commit/f3bd5ff885543fe5bdf61f22373fa9cdcba68f04): [ JenspederM/test/separate_unit_integration](https://github.com/JenspederM/kedro-databricks/pull/55) (JenspederM)
-  [`fdf924f`](https://github.com/JenspederM/kedro-databricks/commit/fdf924fe97d45e7582ddc3aef1509ef9afca6629): [ npfp/feat/conf-source](https://github.com/JenspederM/kedro-databricks/pull/52) (JenspederM)

### Fix

-  [`d0f6ef9`](https://github.com/JenspederM/kedro-databricks/commit/d0f6ef9f169b2bea5267b28b6ad17e13f0b45b9b):  adds support for another conf path# (JenspederM)
-  [`7396a08`](https://github.com/JenspederM/kedro-databricks/commit/7396a08d850baea21ba2ca2ef6f411229724670e):  adds support for another conf path# (JensPederM)

### Other Changes

-  [`4bfcbc7`](https://github.com/JenspederM/kedro-databricks/commit/4bfcbc74c2430dba3ae3e79cfea4c9c0ebd069e4):  separate tests in unit and integration (JensPederM)
-  [`3b7465d`](https://github.com/JenspederM/kedro-databricks/commit/3b7465d850023e22c668dbd0f0197e3b4857b41c):  update kedro dependency (JensPederM)
-  [`6f90db2`](https://github.com/JenspederM/kedro-databricks/commit/6f90db280c7feb2908fd9db46bbd887d9c20bce3):  update pre-commits and disable too-many-arguments (JensPederM)

## 0.3.0 (2024-09-14)

### Pull Requests

-  [`743feaa`](https://github.com/JenspederM/kedro-databricks/commit/743feaa3827ca48a13262ad36496753e7cfa8e85): [ JenspederM/style/lint-fix](https://github.com/JenspederM/kedro-databricks/pull/51) (JenspederM)
-  [`f1dabb2`](https://github.com/JenspederM/kedro-databricks/commit/f1dabb206985e4d99033f524de9dd281e44a7e97): [ JenspederM/style/lint-fix](https://github.com/JenspederM/kedro-databricks/pull/50) (JenspederM)
-  [`ec94eb0`](https://github.com/JenspederM/kedro-databricks/commit/ec94eb0a1279ab76b481a9fcb43e27284da51a67): [ JenspederM/style/lint-fix](https://github.com/JenspederM/kedro-databricks/pull/49) (JenspederM)
-  [`cffb650`](https://github.com/JenspederM/kedro-databricks/commit/cffb650d214d310ed5f3eee6656b808819406bf9): [ JenspederM/style/lint-fix](https://github.com/JenspederM/kedro-databricks/pull/48) (JenspederM)
-  [`c42d303`](https://github.com/JenspederM/kedro-databricks/commit/c42d303ead67ec35cd591e1be8d8980e6691fa0e): [ JenspederM/test/add-tests-for-new-run](https://github.com/JenspederM/kedro-databricks/pull/47) (JenspederM)
-  [`4cc92c4`](https://github.com/JenspederM/kedro-databricks/commit/4cc92c46077e73d4b587942d21341cd7e79041d3): [ JenspederM/feat/support-new-run](https://github.com/JenspederM/kedro-databricks/pull/44) (JenspederM)

### Fix

-  [`11226b0`](https://github.com/JenspederM/kedro-databricks/commit/11226b0fa0c3d0fde15976523209870552dc3ea9):  entry_point is separated by hyphens (Jens Peder Meldgaard)

### Other Changes

-  [`cec3bc8`](https://github.com/JenspederM/kedro-databricks/commit/cec3bc855b2885af370090d621e800300b0034ec):  add select to ruff lint (Jens Peder Meldgaard)
-  [`1ea5c6e`](https://github.com/JenspederM/kedro-databricks/commit/1ea5c6e2b07c2985ac8c6fc16f820aec5c72d93e):  update dependencies (Jens Peder Meldgaard)

## 0.2.1 (2024-09-02)

### Pull Requests

-  [`1271feb`](https://github.com/JenspederM/kedro-databricks/commit/1271feb1e2b1106884645bc7823781149b01e6a4): [ JenspederM/fix/release-pipeline](https://github.com/JenspederM/kedro-databricks/pull/46) (JenspederM)

### Feat

-  [`0540b00`](https://github.com/JenspederM/kedro-databricks/commit/0540b0058d55ce2d6088d59e3e10ce58697e29a1):  Make changes necessary to utilize run in kedro>=0.19.8 (JensPederM)

### Fix

-  [`1271feb`](https://github.com/JenspederM/kedro-databricks/commit/1271feb1e2b1106884645bc7823781149b01e6a4):  project must be build to be listed (JenspederM)
-  [`8937bb1`](https://github.com/JenspederM/kedro-databricks/commit/8937bb108c5e234933673b5a7db25a9b15621a3c):  project must be build to be listed (Jens Peder Meldgaard)
-  [`eac1098`](https://github.com/JenspederM/kedro-databricks/commit/eac10980db845284151d526345c1a2317c70382c):  project must be build to be listed (Jens Peder Meldgaard)
-  [`3451c8e`](https://github.com/JenspederM/kedro-databricks/commit/3451c8e3c24440eae5e909f9ed74ac526a38ba78):  log target path when uploading config (JensPederM)
-  [`0540b00`](https://github.com/JenspederM/kedro-databricks/commit/0540b0058d55ce2d6088d59e3e10ce58697e29a1):  use __main__ when kedro > 0.19.8 (JensPederM)

### Other Changes

-  [`5619a7f`](https://github.com/JenspederM/kedro-databricks/commit/5619a7f0efca1c806271826ba0827b4cc3a15c43):  add commitizen to publish pipeline (Jens Peder Meldgaard)
-  [`9bacb23`](https://github.com/JenspederM/kedro-databricks/commit/9bacb23a2c2a07ede9cee2f46a6ecb4d0d89ecc3):  update dependencies (JensPederM)
